package com.xhu.controller;

import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.UUID;

@Controller
public class UploadController {
    @RequestMapping("/fileUpload")
    public String upload(HttpServletRequest request) throws Exception {
        //创建文件夹
        // 1.设置创建文件夹的真实路径
        String realPath = request.getSession().getServletContext().getRealPath("/upload");
        File file=new File(realPath);
        // 2.判断该目录是否存在，如果不存在，创建目录
        if (!file.exists()){
            file.mkdirs();
        }
        //分析请求体，找到上传文件数据
        // 1.创建磁盘文件工厂
        DiskFileItemFactory factory = new DiskFileItemFactory();
        // 2.创建上传数据分析器对象
        ServletFileUpload upload = new ServletFileUpload(factory);
        // 3.利用分析器对象解析请求体，返回所有数据项
        List<FileItem> fileItems = upload.parseRequest(request);
        // 4.遍历所有数据，找到文件项（非表单项）
        for (FileItem fileItem:fileItems){
            if (!fileItem.isFormField()){
                //将文件数据写入文件夹
                // 1.获取文件名
                String name = fileItem.getName();
                // 2.将文件写入磁盘
                fileItem.write(new File(file,name));
                // 3.删除内存中的临时文件
                fileItem.delete();
            }
        }
        return "index";
    }
    //MultipartFile的参数名必须和jsp文件空间的name属性一致
    @RequestMapping("/fileUpload2")
    public String upload2(MultipartFile file,HttpServletRequest request) throws IOException {
        String realPath = request.getSession().getServletContext().getRealPath("/upload");
        File dir=new File(realPath);
        //创建文件夹,存放上传文件
        if (!dir.exists()){
            dir.mkdirs();
        }
        //将上传的数据写到文件夹的文件中
        //1.拿到上传的文件名
        String filename = file.getOriginalFilename();
        filename= UUID.randomUUID()+"_"+filename;
        //2.创建一个空文件
        File newFile = new File(dir,filename);
        //3.将数据写入空文件
        file.transferTo(newFile);

        return "index";
    }
    @RequestMapping("/fileUpload3")
    public String upload3(MultipartFile files[],String username,HttpServletRequest request) throws IOException {
        System.out.println(username);
        //创建文件夹,存放上传文件
        String realPath = request.getSession().getServletContext().getRealPath("/upload");
        File dir = new File(realPath);
        if (!dir.exists()){
            dir.mkdirs();
        }
        //遍历数组，将上传的文件保存到文件夹
        for (int i=0;i< files.length;i++){
            String filename = files[i].getOriginalFilename();
            filename=UUID.randomUUID()+"_"+filename;
            File file = new File(dir, filename);
            files[i].transferTo(file);
        }
        return "index";
    }
    @RequestMapping("/fileUpload4")
    @ResponseBody
    public String upload4(MultipartFile file,HttpServletRequest request) throws IOException {
        // 创建文件夹，存放上传文件
        String realPath = request.getSession().getServletContext().getRealPath("/upload");
        File dir = new File(realPath);
        if(!dir.exists()){
            dir.mkdirs();
        }

        // 将上传的数据写到文件夹的文件中
        // 1.拿到上传的文件名
        String filename = file.getOriginalFilename();
        filename = UUID.randomUUID()+"_"+filename;
        // 2.创建空文件
        File newFile = new File(dir,filename);
        // 3.将数据写入空文件中
        file.transferTo(newFile);

        // 返回文件路径
        return "/upload/"+filename;
    }
}
